/* $Workfile: Dsp55Def.h $   $Revision: 8 $    $Modtime: 8/27/03 1:06p $  */
#ifndef OTX55_DEF_H
#define OTX55_DEF_H
/*******************************************************************************

  @doc PublicDsp55SdkApi

  Odin TeleSystems Inc.

  SAA-1012-1 OTX DSP C55x Software Development Kit (SDK)

  Macro, Constant, and type definitions for the DSP C55x SDK API

  @module
  Dsp55Def | Constants, Macros, and Types for the DSP C55x SDK

  @contents2
  Dsp55Def.h |

  @index enum struct type | Dsp55Def

  @contents2
  Constants, Macros, and Types (Dsp55Def.h) |

  @head3 DSP C55x SDK Macro, Constant, and Type Reference |

  @index enum struct type | Dsp55Def


*******************************************************************************/

/*******************************************************************************
  MACROS
*******************************************************************************/
/* @type OTXDSP_TRUE | Boolean value TRUE */
#define OTXDSP_TRUE        1
/* @type OTXDSP_FALSE | Boolean value TRUE */
#define OTXDSP_FALSE       0

/* Companding Law Type */
/* @type OTXDSP_ULAW | U-Law Companding */
#define OTXDSP_ULAW       0
/* @type OTXDSP_ALAW | A-Law Companding */
#define OTXDSP_ALAW       1

/* @type OTXDSP_INVALID_HANDLE | Invalid Logical Device Handle Value */
#define OTXDSP_INVALID_HANDLE 0xFFFF

/* @type OTXDSP_SDK_FRAMES_PER_BUF | Number frames in the receive and transmit */
/* buffers. The DMA controller will pick up this many frames from the receive */
/* serial port before he notifies the processing task. The same applies to the */
/* transmit DMA controller. */
#define OTXDSP_SDK_FRAMES_PER_BUF 25

/* @type OTXDSP_NO_TASKREF | No Task Reference */
#define OTXDSP_NO_TASKREF  0xFFFF

/* Commonly used assembly operations */
/* @type C55X_SET_INT_MASK_BIT | Macro for Globally Masking (disable) Interrupts */
#define C55X_SET_INT_MASK_BIT   asm("\t BSET INTM")
/* @type C55X_CLR_INT_MASK_BIT | Macro for Globally Unmasking (enable) Interrupts */
#define C55X_CLR_INT_MASK_BIT   asm("\t BCLR INTM")
/* @type C55X_SET_XF_BIT | Macro for setting the XF bit. Connected to the heart-beat LED. Turns the LED off. */
#define C55X_SET_XF_BIT         asm("\t BSET ST1_XF")
/* @type C55X_CLR_XF_BIT | Macro for clearing the XF bit. Connected to the heart-beat LED. Turns the LED on. */
#define C55X_CLR_XF_BIT         asm("\t BCLR ST1_XF")
/* @type C55X_WAIT_FOR_INT | Macro for making the DSP go idle. It will wake up on any enabled interrupt. */
#define C55X_WAIT_FOR_INT       asm("\t IDLE")
/* @type C55X_NOP | Macro for No-operation */
#define C55X_NOP                asm("\t NOP")
/* @type C55X_CLR_HINT | Macro for clearing the HINT bit. Clearing this bit, followed by setting this bit will generate an interrupt pulse to the host */
#define C55X_CLR_HINT           asm("\t BCLR HINT")
/* @type C55X_SET_HINT | Macro for setting the HINT bit  */
#define C55X_SET_HINT           asm("\t BSET HINT")
      
      
/* @type C55X_SET_LED0_OFF | Macro for turning red LED0 off */
#define C55X_SET_LED0_OFF  (GPIO_FSET(IODATA, IO7D, 1)) 
/* @type C55X_SET_LED0_ON | Macro for turning red LED0 on */
#define C55X_SET_LED0_ON   (GPIO_FSET(IODATA, IO7D, 0)) 
      
/* @type C55X_SET_LED1_OFF | Macro for turning red LED1 off */
#define C55X_SET_LED1_OFF  (GPIO_FSET(IODATA, IO6D, 1)) 
/* @type C55X_SET_LED1_ON | Macro for turning red LED1 on */
#define C55X_SET_LED1_ON   (GPIO_FSET(IODATA, IO6D, 0)) 

/* @type C55X_SET_LED2_OFF | Macro for turning green LED2 off. This LED is normally used as a heart-beat blinking LED */
#define C55X_SET_LED2_OFF  C55X_SET_XF_BIT
/* @type C55X_SET_LED2_ON | Macro for turning green LED2 on. This LED is normally used as a heart-beat blinking LED */
#define C55X_SET_LED2_ON   C55X_CLR_XF_BIT
      


/*******************************************************************************
  TYPES
*******************************************************************************/
struct OtxDspHpiEventBufDiag {
  unsigned short cwFreeBuffer;    // @field Current number of free words in the HPI Event Buffer
  unsigned short cwMinFreeBuffer; // @field Minimum number of free words in the HPI Event Buffer since the application started
  unsigned short coLostEvents;    // @field Number of lost event packets (due to a full buffer) since the application started
};

// @type OtxDspHpiDiag | Struct for diagnostics of the HPI Event buffer (events passed from the DSP to the host)
typedef struct OtxDspHpiEventBufDiag OtxDspHpiEventBufDiag;

struct OtxDspTimeStamp {
  unsigned short nHighPart;  // @field Bit 48-63
  unsigned short nMidPart;   // @field Bit 32-47
  unsigned short nLowPart;   // @field Bit 16-31
};

// @type OtxDspTimeStamp | Struct used for passing a 64 bit timestamp for each HPI Event
typedef struct OtxDspTimeStamp OtxDspTimeStamp;

/*******************************************************************************
  GLOBAL VARIABLES
*******************************************************************************/

extern volatile unsigned short *g_h2dCmdAddrP;
extern volatile unsigned short *g_h2dHandleAddrP;
extern volatile unsigned short *g_h2dTaskRefAddrP;
extern volatile unsigned short *g_h2dDataLenAddrP;
extern volatile unsigned short *g_h2dDataAddrP;

extern unsigned short g_sqDmaRxBuf[32*OTXDSP_SDK_FRAMES_PER_BUF*2];
extern unsigned short g_sqDmaTxBuf[32*OTXDSP_SDK_FRAMES_PER_BUF*2];

extern OtxDspHpiEventBufDiag g_hpiEventBufDiag;

extern OtxDspTimeStamp g_timeStamp;

extern volatile short g_bGotDmaRxInterrupt;
extern volatile short g_bGotDmaTxInterrupt;
extern volatile short g_bGotHostPortInterrupt;
extern volatile short g_bDmaRxHalf;
extern volatile short g_bDmaTxHalf;

extern Uint32 g_nRevtCounter;
extern Uint32 g_nXevtCounter;
extern Uint16 g_nDmaRxTimeoutCounter;
extern Uint16 g_nDmaRxDropCounter;
extern Uint16 g_nDmaTxTimeoutCounter;
extern Uint16 g_nDmaTxDropCounter;


#endif /* OTX55_DEF_H */

